@@ -6,9 +6,6 @@ use autodie;
 
 use Socket;
 
-# bug in this module: it breaks when loaded dynamically
-use Socket::MsgHdr;
-
 use Data::Dumper;
 
 use FindBin;
@@ -16,11 +13,11 @@ use lib "$FindBin::Bin/../lib";
 
 use Protocol::DBus::Client;
 
-my $dbus = Protocol::DBus::Client::system();
+my $dbus = $> ? Protocol::DBus::Client::login_session() ? Protocol::DBus::Client::system();
 
 $dbus->preserve_variant_signatures(1);
 
-$dbus->do_authn();
+$dbus->initialize();
 
 my $got_response;
 
