@@ -11,12 +11,9 @@ use Data::Dumper;
 use Protocol::DBus;
 use Protocol::DBus::Client;
 
-# https://rt.cpan.org/Public/Bug/Display.html?id=127115
-use Socket::MsgHdr;
+my $dbus = $> ? Protocol::DBus::Client::login_session() ? Protocol::DBus::Client::system();
 
-my $dbus = Protocol::DBus::Client::system();
-
-$dbus->do_authn();
+$dbus->initialize();
 
 $dbus->get_message();
 
