@@ -3,7 +3,7 @@ package Protocol::DBus;
 use strict;
 use warnings;
 
-our $VERSION = '0.05-TRIAL2';
+our $VERSION = '0.07-TRIAL2';
 
 =encoding utf8
 
@@ -17,7 +17,8 @@ Protocol::DBus - D-Bus in pure Perl
 
 For blocking I/O:
 
-    $dbus->do_authn();
+    # Authentication and “Hello” call/response:
+    $dbus->initialize();
 
     $dbus->send_call(
         path => '/org/freedesktop/DBus',
@@ -41,8 +42,8 @@ For non-blocking I/O:
     # the following is just for demonstration:
     vec( my $mask, $fileno, 1 ) = 1;
 
-    while (!$dbus->do_authn()) {
-        if ($dbus->authn_pending_send()) {
+    while (!$dbus->initialize()) {
+        if ($dbus->init_pending_send()) {
             select( undef, my $wout = $mask, undef, undef );
         }
         else {
@@ -74,6 +75,13 @@ For non-blocking I/O:
 This is an original, pure-Perl implementation of client logic for
 L<the D-Bus protocol|https://dbus.freedesktop.org/doc/dbus-specification.html>.
 
+It’s not much more than an implementation of the wire protocol; it doesn’t
+know about objects, services, or anything else besides the actual messages.
+That said, what’s here already should allow implementation of anything you
+can do with D-Bus; moreover, it would not be difficult to implement
+convenience logic—e.g., to mimic interfaces like L<Net::DBus>—on top of
+what is here now.
+
 Right now this distribution is an experimental effort. If you use it in your
 project, be sure to check the changelog before deploying a new version. Please
 file bug reports as appropriate.
@@ -84,4 +92,33 @@ See L<Protocol::DBus::Client> and the above sample for a starting point.
 
 See the distribution’s F<examples/> directory.
 
+=head1 NOTES
+
+=over
+
+=item * UNIX FD support requires that L<Socket::MsgHdr> be loaded at
+authentication time.
+
+=item * EXTERNAL and DBUS_COOKIE_SHA1 authentication is supported.
+
+=back
+
+=head1 TODO
+
+=over
+
+=item * Add conveniences like match rule logic.
+
+=item * Improve parsing of bus paths in environment variables.
+
+=item * Add more tests.
+
+=back
+
+=head1 SEE ALSO
+
+L<Net::DBus> uses libdbus (via XS) as its backend. It’s more mature and
+more idiomatic as to how a D-Bus application is normally written, but
+it’s also heavier, and it doesn’t appear to support passing filehandles.
+
 =cut
